pub struct FileOverride { /* private fields */ }Expand description
Read the identifier from a single-line file.
Skipped when the file does not exist, is empty, or contains only whitespace. Returns an I/O error for permission problems or other unexpected read failures.
Implementations